@@ -277,7 +277,7 @@ pref("ldap_2.servers.history.isOffline",						false);
 // default mapping of addressbook properties to ldap attributes
 pref("ldap_2.servers.default.attrmap.FirstName", "givenName");
 pref("ldap_2.servers.default.attrmap.LastName", "sn,surname");
-pref("ldap_2.servers.default.attrmap.DisplayName", "displayName,cn,commonname");
+pref("ldap_2.servers.default.attrmap.DisplayName", "cn,commonname");
 pref("ldap_2.servers.default.attrmap.NickName", "mozillaNickname,xmozillanickname");
 pref("ldap_2.servers.default.attrmap.PrimaryEmail", "mail");
 pref("ldap_2.servers.default.attrmap.SecondEmail", "mozillaSecondEmail,xmozillasecondemail");
@@ -627,7 +627,7 @@ pref("mailnews.fakeaccount.server", "");
 
 // message display properties
 pref("mailnews.message_display.disable_remote_image", false);
-pref("mailnews.message_display.allow.plugins", true);
+pref("mailnews.message_display.allow.plugins", false);
 
 // default msg compose font prefs
 pref("msgcompose.font_face",                "");
@@ -659,9 +659,9 @@ pref("mail.standalone", false);
 // the users last used preference.
 pref("mailnews.import.text.skipfirstrecord", true);
 
-//@line 669 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mailnews/mailnews.js"
+//@line 669 "/usr/obj/ports/mozilla-thunderbird-1.5.0.2/mozilla/mailnews/mailnews.js"
 
-//@line 672 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mailnews/mailnews.js"
+//@line 672 "/usr/obj/ports/mozilla-thunderbird-1.5.0.2/mozilla/mailnews/mailnews.js"
 pref("mail.empty_trash", false);
 
 pref("mail.check_new_mail", true);
@@ -678,5 +678,5 @@ pref("news.show_first_unread", false);
 pref("news.sash_geometry", "");
 pref("mail.signature_date", 0);
 
-//@line 691 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mailnews/mailnews.js"
+//@line 691 "/usr/obj/ports/mozilla-thunderbird-1.5.0.2/mozilla/mailnews/mailnews.js"
 
