@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/extensions/newsblog/content/Feed.js"
+//@line 37 "/usr/obj/ports/mozilla-thunderbird-1.5.0.2/mozilla/mail/extensions/newsblog/content/Feed.js"
 
 
 // error codes used to inform the consumer about attempts to download a feed
@@ -171,7 +171,13 @@ Feed.prototype =
     if (feed.downloadCallback) 
     {
       // if the http status code is a 304, then the feed has not been modified since we last downloaded it.
-      feed.downloadCallback.downloaded(feed, request.status == 304 ? kNewsBlogNoNewItems : kNewsBlogRequestFailure);
+      var error = kNewsBlogRequestFailure;
+      try
+      {
+        if (request.status == 304)
+          error = kNewsBlogNoNewItems;
+      } catch (ex) {}
+      feed.downloadCallback.downloaded(feed, error);
     }
     
     FeedCache.removeFeed(url);
