@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/msgHdrViewOverlay.js"
+//@line 38 "/usr/obj/ports/mozilla-thunderbird-1.5.0.2/mozilla/mail/base/content/msgHdrViewOverlay.js"
 
 
 /* This is where functions related to displaying the headers for a selected message in the
@@ -1464,8 +1464,8 @@ function addAttachmentToPopup(popup, attachment, attachmentIndex)
       openpopup.appendChild(menuseparator);
 
       menuitementry = document.createElement('menuitem');
-      menuitementry.attachment = attachment;
-      menuitementry.setAttribute('oncommand', 'this.attachment.detachAttachment()'); 
+      menuitementry.attachment = cloneAttachment(attachment);
+      menuitementry.setAttribute('oncommand', 'detachAttachment(this.attachment, true)'); 
       menuitementry.setAttribute('label', gDetachLabel); 
       menuitementry.setAttribute('accesskey', gDetachLabelAccesskey); 
       if (attachment.contentType == 'text/x-moz-deleted' || !canDetach)
@@ -1473,8 +1473,8 @@ function addAttachmentToPopup(popup, attachment, attachmentIndex)
       menuitementry = openpopup.appendChild(menuitementry);
 
       menuitementry = document.createElement('menuitem');
-      menuitementry.attachment = attachment;
-      menuitementry.setAttribute('oncommand', 'this.attachment.deleteAttachment()'); 
+      menuitementry.attachment = cloneAttachment(attachment);
+      menuitementry.setAttribute('oncommand', 'detachAttachment(this.attachment, false)'); 
       menuitementry.setAttribute('label', gDeleteLabel); 
       menuitementry.setAttribute('accesskey', gDeleteLabelAccesskey); 
       if (attachment.contentType == 'text/x-moz-deleted' || !canDetach)
