@@ -1,4 +1,4 @@
-//@line 43 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/msgMail3PaneWindow.js"
+//@line 43 "/usr/obj/ports/mozilla-thunderbird-1.5.0.2/mozilla/mail/base/content/msgMail3PaneWindow.js"
 
 /* This is where functions related to the 3 pane window are kept */
 
@@ -35,6 +35,7 @@ var gCurrentDisplayedMessage = null;
 var gNextMessageAfterDelete = null;
 var gNextMessageAfterLoad = null;
 var gNextMessageViewIndexAfterDelete = -2;
+var gSelectedIndexWhenDeleting = -1;
 var gCurrentlyDisplayedMessage=nsMsgViewIndex_None;
 var gStartFolderUri = null;
 var gStartMsgKey = nsMsgKey_None;
@@ -1513,7 +1514,10 @@ function SetNextMessageAfterDelete()
   var treeSelection = GetThreadTree().view.selection;
 
   if (treeSelection.isSelected(treeSelection.currentIndex))
+  {
     gNextMessageViewIndexAfterDelete = gDBView.msgToSelectAfterDelete;
+    gSelectedIndexWhenDeleting = treeSelection.currentIndex;
+  }
   else if(gDBView.removeRowOnMoveOrDelete)
   {
     // Only set gThreadPaneDeleteOrMoveOccurred to true if the message was
