@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/phishingDetector.js"
+//@line 38 "/usr/obj/ports/mozilla-thunderbird-1.5.0.2/mozilla/mail/base/content/phishingDetector.js"
 
 // Dependencies: 
 // gPrefBranch, gBrandBundle, gMessengerBundle should already be defined
@@ -93,6 +93,11 @@ function isPhishingURL(aLinkNode, aSilentMode)
 function misMatchedHostWithLinkText(aLinkNode, aHrefURL, aLinkTextURL)
 {
   var linkNodeText = gatherTextUnder(aLinkNode);    
+
+  // gatherTextUnder puts a space between each piece of text it gathers,
+  // so strip the spaces out (see bug 326082 for details).
+  linkNodeText = linkNodeText.replace(/ /g, "");
+
   // only worry about http and https urls
   if (linkNodeText)
   {
